@@ -1,7 +1,7 @@
 package Net::RackSpace::CloudServers;
 
 BEGIN {
-    $Net::RackSpace::CloudServers::VERSION = '0.12';
+    $Net::RackSpace::CloudServers::VERSION = '0.13';
 }
 use warnings;
 use strict;
@@ -15,7 +15,6 @@ use LWP::UserAgent::Determined;
 use JSON;
 use YAML;
 use Carp;
-use 5.010_000;
 
 our $DEBUG = 0;
 
@@ -168,8 +167,9 @@ sub get_server {
         [ 'X-Auth-Token' => $self->token ]
     );
     my $response = $self->_request($request);
-    return if $response->code ~~ [ 204, 404 ];
-    confess 'Unknown error' . $response->code unless ( $response->code ~~ [ 200, 203 ] );
+    return if scalar grep { $response->code eq $_ } ( 204, 404 );
+    confess 'Unknown error' . $response->code
+      unless scalar grep { $response->code eq $_ } ( 200, 203 );
     my @servers;
     my $hash_response = from_json( $response->content );
     warn Dump($hash_response) if $DEBUG;
@@ -242,7 +242,8 @@ sub get_flavor {
     );
     my $response = $self->_request($request);
     return if $response->code == 204;
-    confess 'Unknown error ' . $response->code unless ( $response->code ~~ [ 200, 203 ] );
+    confess 'Unknown error ' . $response->code
+      unless scalar grep { $response->code eq $_ } ( 200, 203 );
     my $hash_response = from_json( $response->content );
     warn Dump($hash_response) if $DEBUG;
 
@@ -296,7 +297,8 @@ sub get_image {
     );
     my $response = $self->_request($request);
     return if $response->code == 204;
-    confess 'Unknown error ' . $response->code unless ( $response->code ~~ [ 200, 203 ] );
+    confess 'Unknown error' . $response->code
+      unless scalar grep { $response->code eq $_ } ( 200, 203 );
     my $hash_response = from_json( $response->content );
     warn Dump($hash_response) if $DEBUG;
 
@@ -351,7 +353,8 @@ sub delete_image {
         ],
     );
     my $response = $self->_request($request);
-    confess 'Unknown error ' . $response->code unless ( $response->code ~~ [ 202, 204 ] );
+    confess 'Unknown error' . $response->code
+      unless scalar grep { $response->code eq $_ } ( 200, 204 );
     return;
 }
 
@@ -361,7 +364,7 @@ Net::RackSpace::CloudServers - Interface to RackSpace CloudServers via API
 
 =head1 VERSION
 
-version 0.12
+version 0.13
 
 =head1 SYNOPSIS
 
